==> yeecli-0.0.11.tar.gz: yeecli-0.0.11/yeecli/cli.py <==
import os
import sys
try:
    import ConfigParser
except ImportError:
    import configparser as ConfigParser

import click
import yeelight

try:
    import tbvaccine
    tbvaccine.add_hook()
except:
    pass

try:
    from . import __version__
except (SystemError, ValueError):
    from __init__ import __version__

BULB = None


def hex_color_to_rgb(color):
    "Convert a hex color string to an RGB tuple."
    color = color.strip("#")
    try:
        red, green, blue = tuple(int(color[i:i + 2], 16) for i in (0, 2, 4))
    except:
        red, green, blue = (255, 0, 0)
    return red, green, blue


def param_or_config(param, config, section, name, default):
    """
    Return a parameter, config item or default, in thar order of
    priority.
    """
    try:
        conf_param = config.get(section, name)
    except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
        conf_param = None

    try:
        # Try to see if this parameter is an integer.
        conf_param = int(conf_param)
    except:
        pass

    return param or conf_param or default


@click.group()
@click.version_option(
    version=__version__,
    prog_name="yeecli",
    message="%(prog)s %(version)s: And there was light."
)
@click.option('--ip', metavar='IP', help="The bulb's IP address.")
@click.option('--port', metavar='PORT', help="The bulb's port.", type=int)
@click.option("--effect", metavar='EFFECT', help="The transition effect.", type=click.Choice(['smooth', 'sudden']))
@click.option("--duration", metavar="DURATION_MS", help="The transition effect duration.", type=click.IntRange(1, 60000, clamp=True))
@click.option("--bulb", metavar="NAME", default="default", help="The name of the bulb in the config file.", type=str)
def cli(ip, port, effect, duration, bulb):
    """
    yeecli is a command-line utility for controlling the YeeLight RGB LED
    lightbulb.
    """
    global BULB

    config = ConfigParser.SafeConfigParser()
    config.read([os.path.expanduser('~/.config/yeecli/yeecli.cfg')])

    ip = param_or_config(ip, config, bulb, "ip", None)
    port = param_or_config(port, config, bulb, "port", 55443)
    effect = param_or_config(effect, config, bulb, "effect", "sudden")
    duration = param_or_config(duration, config, bulb, "duration", 500)

    if not ip:
        click.echo("No IP address specified.")
        sys.exit(1)

    BULB = yeelight.Bulb(
        ip=ip,
        port=port,
        effect=effect,
        duration=duration,
        auto_on=True
    )


@cli.command()
@click.argument("value", type=click.IntRange(1, 100, clamp=True))
def brightness(value):
    """Set the brightness of the bulb."""
    click.echo("Setting the bulb to {} brightness...".format(value))
    BULB.set_brightness(value)


@cli.command()
@click.argument("degrees", type=click.IntRange(1700, 6500, clamp=True))
def temperature(degrees):
    """Set the color temperature of the bulb."""
    click.echo("Setting the bulb's color temperature to {}...".format(degrees))
    BULB.set_color_temp(degrees)


@cli.command()
@click.argument("hue", type=click.IntRange(0, 359, clamp=True))
@click.argument("saturation", type=click.IntRange(0, 100, clamp=True))
def hsv(hue, saturation):
    """Set the HSV value of the bulb."""
    click.echo("Setting the bulb to HSV {}, {}...".format(hue, saturation))
    BULB.set_hsv(hue, saturation)


@cli.command()
@click.argument("hex_color", type=str)
def rgb(hex_color):
    """Set the RGB value of the bulb."""
    red, green, blue = hex_color_to_rgb(hex_color)
    click.echo("Setting the bulb to RGB {}...".format(hex_color))
    BULB.set_rgb(red, green, blue)


@cli.command()
def toggle():
    """Toggle the bulb's state on or off."""
    click.echo("Toggling the bulb...")
    BULB.toggle()


@cli.command()
@click.argument("hex_color", type=str)
@click.option("--pulses", metavar='COUNT', type=int, default=2,
              help="The number of times to pulse.")
def pulse(hex_color, pulses):
    """Pulse the bulb in a specific color."""
    red, green, blue = hex_color_to_rgb(hex_color)
    duration = 250
    transitions = [
        yeelight.flow.RGBTransition(red, green, blue, duration=duration),
        yeelight.flow.RGBTransition(red, green, blue, duration=duration, brightness=1),
    ]
    flow = yeelight.Flow(count=pulses, transitions=transitions)
    BULB.start_flow(flow)


@cli.command()
@click.argument("state", type=click.Choice(['on', 'off']))
def turn(state):
    """Turn the bulb on or off."""
    click.echo("Turning the bulb {}...".format(state))
    if state == "on":
        BULB.turn_on()
    elif state == "off":
        BULB.turn_off()


@cli.command()
def save():
    """Save the current settings as default."""
    click.echo("Saving settings...")
    BULB.set_default()


@cli.command()
def status():
    """Show the bulb's status."""
    click.echo("Bulb parameters:")
    for key, value in BULB.get_properties().items():
        click.echo("* {}: {}".format(key, value))

if __name__ == "__main__":
    cli()

==> yeecli-0.0.12.tar.gz: yeecli-0.0.12/yeecli/cli.py <==
import os
import sys
try:
    import ConfigParser
except ImportError:
    import configparser as ConfigParser

import click
import yeelight

try:
    import tbvaccine
    tbvaccine.add_hook()
except:
    pass

try:
    from . import __version__
except (SystemError, ValueError):
    from __init__ import __version__

BULB = None


def hex_color_to_rgb(color):
    "Convert a hex color string to an RGB tuple."
    color = color.strip("#")
    try:
        red, green, blue = tuple(int(color[i:i + 2], 16) for i in (0, 2, 4))
    except:
        red, green, blue = (255, 0, 0)
    return red, green, blue


def param_or_config(param, config, section, name, default):
    """
    Return a parameter, config item or default, in thar order of
    priority.
    """
    try:
        conf_param = config.get(section, name)
    except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
        conf_param = None

    try:
        # Try to see if this parameter is an integer.
        conf_param = int(conf_param)
    except:
        pass

    return param or conf_param or default


@click.group()
@click.version_option(
    version=__version__,
    prog_name="yeecli",
    message="%(prog)s %(version)s: And there was light."
)
@click.option('--ip', metavar='IP', help="The bulb's IP address.")
@click.option('--port', metavar='PORT', help="The bulb's port.", type=int)
@click.option("--effect", metavar='EFFECT', help="The transition effect.", type=click.Choice(['smooth', 'sudden']))
@click.option("--duration", metavar="DURATION_MS", help="The transition effect duration.", type=click.IntRange(1, 60000, clamp=True))
@click.option("--bulb", metavar="NAME", default="default", help="The name of the bulb in the config file.", type=str)
@click.option("--auto-on/--no-auto-on", default=True)
def cli(ip, port, effect, duration, bulb, auto_on):
    """
    yeecli is a command-line utility for controlling the YeeLight RGB LED
    lightbulb.
    """
    global BULB

    config = ConfigParser.SafeConfigParser()
    config.read([os.path.expanduser('~/.config/yeecli/yeecli.cfg')])

    ip = param_or_config(ip, config, bulb, "ip", None)
    port = param_or_config(port, config, bulb, "port", 55443)
    effect = param_or_config(effect, config, bulb, "effect", "sudden")
    duration = param_or_config(duration, config, bulb, "duration", 500)

    if not ip:
        click.echo("No IP address specified.")
        sys.exit(1)

    BULB = yeelight.Bulb(
        ip=ip,
        port=port,
        effect=effect,
        duration=duration,
        auto_on=auto_on,
    )


@cli.command()
@click.argument("value", type=click.IntRange(1, 100, clamp=True))
def brightness(value):
    """Set the brightness of the bulb."""
    click.echo("Setting the bulb to {} brightness...".format(value))
    BULB.set_brightness(value)


@cli.command()
@click.argument("degrees", type=click.IntRange(1700, 6500, clamp=True))
def temperature(degrees):
    """Set the color temperature of the bulb."""
    click.echo("Setting the bulb's color temperature to {}...".format(degrees))
    BULB.set_color_temp(degrees)


@cli.command()
@click.argument("hue", type=click.IntRange(0, 359, clamp=True))
@click.argument("saturation", type=click.IntRange(0, 100, clamp=True))
def hsv(hue, saturation):
    """Set the HSV value of the bulb."""
    click.echo("Setting the bulb to HSV {}, {}...".format(hue, saturation))
    BULB.set_hsv(hue, saturation)


@cli.command()
@click.argument("hex_color", type=str)
def rgb(hex_color):
    """Set the RGB value of the bulb."""
    red, green, blue = hex_color_to_rgb(hex_color)
    click.echo("Setting the bulb to RGB {}...".format(hex_color))
    BULB.set_rgb(red, green, blue)


@cli.command()
def toggle():
    """Toggle the bulb's state on or off."""
    click.echo("Toggling the bulb...")
    BULB.toggle()


@cli.command()
@click.argument("hex_color", type=str)
@click.option("--pulses", metavar='COUNT', type=int, default=2,
              help="The number of times to pulse.")
def pulse(hex_color, pulses):
    """Pulse the bulb in a specific color."""
    red, green, blue = hex_color_to_rgb(hex_color)
    duration = 250
    transitions = [
        yeelight.flow.RGBTransition(red, green, blue, duration=duration),
        yeelight.flow.RGBTransition(red, green, blue, duration=duration, brightness=1),
    ]

    # Get the initial bulb state.
    if BULB.get_properties().get("power", "off") == "off":
        action = yeelight.Flow.actions.off
    else:
        action = yeelight.Flow.actions.recover

    flow = yeelight.Flow(count=pulses, action=action, transitions=transitions)

    BULB.start_flow(flow)


@cli.command()
@click.argument("state", type=click.Choice(['on', 'off']))
def turn(state):
    """Turn the bulb on or off."""
    click.echo("Turning the bulb {}...".format(state))
    if state == "on":
        BULB.turn_on()
    elif state == "off":
        BULB.turn_off()


@cli.command()
def save():
    """Save the current settings as default."""
    click.echo("Saving settings...")
    BULB.set_default()


@cli.command()
def status():
    """Show the bulb's status."""
    click.echo("Bulb parameters:")
    for key, value in BULB.get_properties().items():
        click.echo("* {}: {}".format(key, value))

if __name__ == "__main__":
    cli()
